Products.ZMySQLDA — Products.ZMySQLDA 4.0b2.dev0 documentation

# Products.ZMySQLDA

This is the MySQL database adapter product for Zope.

## Compatibility

- `Zope2` 2.13.26 and up under Python 2.7 in conjunction with `Products.ZSQLMethods` up to and including 2.13.5.
- `Zope` 4 after 4.0beta5 under either Python 2.7, 3.5 or 3.6.
- MySQL versions 3.22 and later including MariaDB. You need version 4.1 or higher for unicode support.

## Narrative documentation

- Connection Strings
- Usage from the Zope ZMI
  - Status
  - Properties
  - Test
  - Security
  - Undo
  - Ownership
  - Interfaces
  - Browse
- Development
  - Getting the source code
  - Bug tracker
  - Running the tests using `zc.buildout`
  - Running the functional tests
  - Building the documentation using `zc.buildout`
  - Making a release
- Contributors
- Products.ZMySQLDA change log
  - 4.0b2 (unreleased)
  - 4.0b1 (2018-06-11)
  - 3.1.1
  - 3.1
  - 3.0
  - 3.0beta1
  - 3.0alpha4
  - 3.0alpha3
  - 3.0alpha2
  - 3.0alpha1
  - 2.0.9
  - 2.0.8
  - 2.0.7
  - 2.0.6
  - 2.0.5
  - 2.0.4
  - 2.0.0

## API documentation

- `Products.ZMySQLDA.DA.Connection`

## Indices and tables

- Index
- Module Index
- Search Page
- Glossary